#ifndef _FOO_PLAYLIST_H_FOO_
#define _FOO_PLAYLIST_H_FOO_

#include <hildon/hildon.h>

#include "userdata.h"

/* playlist data */
enum {
    PLAYLISTS_COL_ID = 0,
    PLAYLISTS_COL_NAME,
    PLAYLISTS_COL_AUTHOR,
    PLAYLISTS_NUM_COLS
};

enum {
    PLAYLIST_COL_TRACK = 0,
    PLAYLIST_COL_TITLE,
    PLAYLIST_COL_ARTIST,
    PLAYLIST_COL_ALBUM,
    PLAYLIST_NUM_COLS
};

enum {
    ALBUM_COL_TRACK = 0,
    ALBUM_COL_TITLE,
    ALBUM_COL_LENGTH,
    ALBUM_NUM_COLS
};

enum {
    QUEUE_COL_TRACK = 0,
    QUEUE_COL_TITLE,
    QUEUE_COL_ARTIST,
    QUEUE_COL_LENGTH,
    QUEUE_NUM_COLS
};

GtkTreeView* yaspot_playlist_view_new();
GtkTreeView* yaspot_playlists_view_new();
GtkTreeView* yaspot_playlist_album_new();
GtkTreeView* yaspot_playlist_queue_new();



#endif

// vim: expandtab shiftwidth=4

